==> haskell-aeson-compat-0.3.9-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-F10Wf95ySSZ6DyCzL47XB9
key: aeson-compat-0.3.9-F10Wf95ySSZ6DyCzL47XB9
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: c93f58ead49d15dc02f83f3e31063f17
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-F10Wf95ySSZ6DyCzL47XB9
depends:
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL
    attoparsec-0.13.2.2-FR6Av5BO2dBDiw4NtrzSsH
    attoparsec-iso8601-1.0.1.0-2NSpOEfgp4yF3O3F6uSKdJ base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.9-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-EszY4PtCqn3IN4AuWucFfN
key: aeson-compat-0.3.9-EszY4PtCqn3IN4AuWucFfN
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: e5e3b134820ac4c99370f22ecd1ced3e
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-EszY4PtCqn3IN4AuWucFfN
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal
    attoparsec-iso8601-1.0.1.0-8lKhF7jfReyAgwsQZUknPQ base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
